@@ -1,6 +1,6 @@
 /* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-#ifndef H_PROCMAN_ARGV_1205873424
-#define H_PROCMAN_ARGV_1205873424
+#ifndef _GSM_ARGV_H_
+#define _GSM_ARGV_H_
 
 #include <glibmm/optiongroup.h>
 
@@ -20,4 +20,4 @@ namespace procman
     };
 }
 
-#endif // H_PROCMAN_ARGV_1205873424
+#endif /* _GSM_ARGV_H_ */
